@@ -240,7 +240,7 @@ void ButtonPanel::examineButton( std::string name, int showInfo ){
         if( b->isEnabled() ){
             b->enable( false );
             char tooltip[2048];
-            snprintf(tooltip, sizeof(tooltip), "%s (Techlevel %.1f required.)", 
+            snprintf(tooltip, sizeof(tooltip), _("%s (Techlevel %.1f required.)"), 
                     createTooltip(selected_module_type, false ).c_str(),
                     requiredTech(selected_module_type));
             b->setTooltip(tooltip);
@@ -274,8 +274,8 @@ void ButtonPanel::examineMenuButtons(){
         } else {
             if( b->isEnabled() ){
                 char tooltip[2048];
-                snprintf(tooltip, sizeof(tooltip), "%s (Techlevel %.1f required.)" 
-                        , createTooltip( type ).c_str(),
+                snprintf(tooltip, sizeof(tooltip), _("%s (Techlevel %.1f required.)"), 
+                        createTooltip( type ).c_str(),
                         requiredTech(type));
                 b->setTooltip( tooltip );
                 b->enable( false );
@@ -653,7 +653,7 @@ void ButtonPanel::chooseButtonClicked(CheckButton* button, int mousebutton )
                     cb->enable();
                     cb->check();
                     // simply simulate button press
-                    menuButtonClicked(cb,SDL_BUTTON_LEFT);
+                    menuButtonClicked(cb,SDL_BUTTON_RIGHT);
                     dynamic_cast<Image*>(cb->getCaption())->setFile(filename);
                 }
             }
@@ -730,10 +730,15 @@ void ButtonPanel::menuButtonClicked(CheckButton* button,int b)
             // get Component
             Component* c=findComponent(mMenus[i]);
             //Check if Techlevel is sufficient.
-            if( enoughTech( mMenuSelected[mMenus[i]] ) && ( b == SDL_BUTTON_LEFT ) ){
+            if( enoughTech( mMenuSelected[mMenus[i]] ) && ( b == SDL_BUTTON_RIGHT ) ){
                 selected_module_type=selected_module=mMenuSelected[mMenus[i]];
                 updateSelectedCost();
                 button->check();
+            }  
+            if( mMenuSelected[mMenus[i]] == selected_module_type ){ //button toggles on every click
+                button->check(); 
+            } else {
+                button->uncheck(); 
             }
             if(c) {
                 // try en-/disabling compoent
@@ -746,18 +751,18 @@ void ButtonPanel::menuButtonClicked(CheckButton* button,int b)
                         {
                             if(i->isEnabled())
                                 i->enable(false);
-                            else if(b!=SDL_BUTTON_LEFT)
+                            else if(b!=SDL_BUTTON_RIGHT)
                                 i->enable(true);
                         }
                     }
                 }
             }
-        } else if(b==SDL_BUTTON_LEFT)  {
+        } else if(b==SDL_BUTTON_RIGHT)  {
             toggleMenu(mMenus[i],false);
             try
             {
                 CheckButton *b=checked_cast<CheckButton>(findComponent(mMenuButtons[i]));
-                // unceck button, ignore disabled buttons
+                // uncheck button, ignore disabled buttons
                 if( b->isEnabled() ){
                     b->uncheck();
                 }
