@@ -870,7 +870,9 @@ void GameView::event(const Event& event)
                 break;       
             }
             if( event.mousebutton == SDL_BUTTON_MIDDLE ) {
-                getMiniMap()->showMpsEnv( getTile( event.mousepos ) );
+                if( inCity( getTile( event.mousepos ) ) ) {
+                    getMiniMap()->showMpsEnv( getTile( event.mousepos ) );
+                }
             }
             break;
         }
@@ -1594,8 +1596,6 @@ int GameView::bulldozeCost( MapPoint tile ){
     if (group == 0) {  /* Can't bulldoze grass. */
         prize = 0; 
     } else {
-        if (group < 7)
-            group--;            /* translate into button type */
         prize = main_groups[group].bul_cost;
     }
     return prize;
